@@ -1,5 +1,6 @@
 # flake8: NOQA: E501
 """Sphinx documentation configuration for tmuxp."""
+
 import contextlib
 import inspect
 import pathlib
@@ -47,6 +48,7 @@ myst_enable_extensions = [
     "substitution",
     "replacements",
     "strikethrough",
+    "linkify",
 ]
 
 templates_path = ["_templates"]
@@ -58,8 +60,8 @@ master_doc = "index"
 project = about["__title__"]
 project_copyright = about["__copyright__"]
 
-version = "%s" % (".".join(about["__version__"].split("."))[:2])
-release = "%s" % (about["__version__"])
+version = "{}".format(".".join(about["__version__"].split("."))[:2])
+release = "{}".format(about["__version__"])
 
 exclude_patterns = ["_build"]
 
@@ -189,7 +191,7 @@ def linkcode_resolve(domain: str, info: t.Dict[str, str]) -> t.Union[None, str]:
     except Exception:
         lineno = None
 
-    linespec = "#L%d-L%d" % (lineno, lineno + len(source) - 1) if lineno else ""
+    linespec = f"#L{lineno}-L{lineno + len(source) - 1}" if lineno else ""
 
     fn = relpath(fn, start=pathlib.Path(tmuxp.__file__).parent)
 
@@ -201,15 +203,14 @@ def linkcode_resolve(domain: str, info: t.Dict[str, str]) -> t.Union[None, str]:
             fn,
             linespec,
         )
-    else:
-        return "{}/blob/v{}/{}/{}/{}{}".format(
-            about["__github__"],
-            about["__version__"],
-            "src",
-            about["__package_name__"],
-            fn,
-            linespec,
-        )
+    return "{}/blob/v{}/{}/{}/{}{}".format(
+        about["__github__"],
+        about["__version__"],
+        "src",
+        about["__package_name__"],
+        fn,
+        linespec,
+    )
 
 
 def remove_tabs_js(app: "Sphinx", exc: Exception) -> None:
