@@ -1,13 +1,15 @@
 """CLI for ``tmuxp convert`` subcommand."""
+
 import argparse
+import locale
 import os
 import pathlib
 import typing as t
 
+from tmuxp import exc
 from tmuxp._internal.config_reader import ConfigReader
 from tmuxp.workspace.finders import find_workspace_file, get_workspace_dir
 
-from .. import exc
 from .utils import prompt_yes_no
 
 if t.TYPE_CHECKING:
@@ -66,10 +68,10 @@ def command_convert(
 
     _, ext = os.path.splitext(workspace_file)
     ext = ext.lower()
-    to_filetype: "AllowedFileTypes"
+    to_filetype: AllowedFileTypes
     if ext == ".json":
         to_filetype = "yaml"
-    elif ext in [".yaml", ".yml"]:
+    elif ext in {".yaml", ".yml"}:
         to_filetype = "json"
     else:
         raise ConvertUnknownFileType(ext)
@@ -86,11 +88,11 @@ def command_convert(
     if (
         not answer_yes
         and prompt_yes_no(f"Convert to <{workspace_file}> to {to_filetype}?")
-        and prompt_yes_no("Save workspace to %s?" % newfile)
+        and prompt_yes_no(f"Save workspace to {newfile}?")
     ):
         answer_yes = True
 
     if answer_yes:
-        with open(newfile, "w") as buf:
+        with open(newfile, "w", encoding=locale.getpreferredencoding(False)) as buf:
             buf.write(new_workspace)
         print(f"New workspace file saved to <{newfile}>.")
