@@ -1,5 +1,7 @@
 """CLI for ``tmuxp freeze`` subcommand."""
+
 import argparse
+import locale
 import os
 import pathlib
 import sys
@@ -7,12 +9,12 @@ import typing as t
 
 from libtmux.server import Server
 
+from tmuxp import exc, util
 from tmuxp._internal.config_reader import ConfigReader
 from tmuxp.exc import TmuxpException
+from tmuxp.workspace import freezer
 from tmuxp.workspace.finders import get_workspace_dir
 
-from .. import exc, util
-from ..workspace import freezer
 from .utils import prompt, prompt_choices, prompt_yes_no
 
 if t.TYPE_CHECKING:
@@ -111,7 +113,7 @@ def command_freeze(
             session = util.get_session(server)
 
         if not session:
-            raise exc.SessionNotFound()
+            raise exc.SessionNotFound
     except TmuxpException as e:
         print(e)
         return
@@ -152,18 +154,18 @@ def command_freeze(
             ),
         )
         dest_prompt = prompt(
-            "Save to: %s" % save_to,
+            f"Save to: {save_to}",
             default=save_to,
         )
         if not args.force and os.path.exists(dest_prompt):
-            print("%s exists. Pick a new filename." % dest_prompt)
+            print(f"{dest_prompt} exists. Pick a new filename.")
             continue
 
         dest = dest_prompt
     dest = os.path.abspath(os.path.relpath(os.path.expanduser(dest)))
     workspace_format = args.workspace_format
 
-    valid_workspace_formats: t.List["CLIOutputFormatLiteral"] = ["json", "yaml"]
+    valid_workspace_formats: t.List[CLIOutputFormatLiteral] = ["json", "yaml"]
 
     def is_valid_ext(stem: t.Optional[str]) -> "TypeGuard[CLIOutputFormatLiteral]":
         return stem in valid_workspace_formats
@@ -183,8 +185,9 @@ def command_freeze(
         workspace_format = extract_workspace_format(dest)
         if not is_valid_ext(workspace_format):
             _workspace_format = prompt_choices(
-                "Couldn't ascertain one of [%s] from file name. Convert to"
-                % ", ".join(valid_workspace_formats),
+                "Couldn't ascertain one of [{}] from file name. Convert to".format(
+                    ", ".join(valid_workspace_formats),
+                ),
                 choices=t.cast(t.List[str], valid_workspace_formats),
                 default="yaml",
             )
@@ -201,12 +204,12 @@ def command_freeze(
     elif workspace_format == "json":
         workspace = configparser.dump(fmt="json", indent=2)
 
-    if args.answer_yes or prompt_yes_no("Save to %s?" % dest):
+    if args.answer_yes or prompt_yes_no(f"Save to {dest}?"):
         destdir = os.path.dirname(dest)
         if not os.path.isdir(destdir):
             os.makedirs(destdir)
-        with open(dest, "w") as buf:
+        with open(dest, "w", encoding=locale.getpreferredencoding(False)) as buf:
             buf.write(workspace)
 
         if not args.quiet:
-            print("Saved to %s." % dest)
+            print(f"Saved to {dest}.")
