@@ -1,5 +1,8 @@
 """Create a tmux workspace from a workspace :py:obj:`dict`."""
+
 import logging
+import os
+import shutil
 import time
 import typing as t
 
@@ -10,14 +13,27 @@ from libtmux.server import Server
 from libtmux.session import Session
 from libtmux.window import Window
 
-from .. import exc
-from ..util import get_current_pane, run_before_script
+from tmuxp import exc
+from tmuxp.util import get_current_pane, run_before_script
 
 logger = logging.getLogger(__name__)
 
-DEFAULT_WIDTH = "800"
-DEFAULT_HEIGHT = "600"
-DEFAULT_SIZE = f"{DEFAULT_WIDTH}x{DEFAULT_HEIGHT}"
+COLUMNS_FALLBACK = 80
+
+
+def get_default_columns() -> int:
+    """Return default session column size use when building new tmux sessions."""
+    return int(
+        os.getenv("TMUXP_DEFAULT_COLUMNS", os.getenv("COLUMNS", COLUMNS_FALLBACK)),
+    )
+
+
+ROWS_FALLBACK = int(os.getenv("TMUXP_DEFAULT_ROWS", os.getenv("ROWS", 24)))
+
+
+def get_default_rows() -> int:
+    """Return default session row size use when building new tmux sessions."""
+    return int(os.getenv("TMUXP_DEFAULT_ROWS", os.getenv("ROWS", ROWS_FALLBACK)))
 
 
 class WorkspaceBuilder:
@@ -158,7 +174,7 @@ class WorkspaceBuilder:
         if plugins is None:
             plugins = []
         if not session_config:
-            raise exc.EmptyWorkspaceException()
+            raise exc.EmptyWorkspaceException
 
         # validation.validate_schema(session_config)
 
@@ -184,7 +200,7 @@ class WorkspaceBuilder:
     def session(self) -> Session:
         """Return tmux session using in workspace builder session."""
         if self._session is None:
-            raise exc.SessionMissingWorkspaceException()
+            raise exc.SessionMissingWorkspaceException
         return self._session
 
     def session_exists(self, session_name: str) -> bool:
@@ -223,19 +239,26 @@ class WorkspaceBuilder:
                     "WorkspaceBuilder.build requires server to be passed "
                     + "on initialization, or pass in session object to here.",
                 )
-            else:
-                new_session_kwargs = {}
-                if "start_directory" in self.session_config:
-                    new_session_kwargs["start_directory"] = self.session_config[
-                        "start_directory"
-                    ]
-                if has_gte_version("2.6"):
-                    new_session_kwargs["x"] = 800
-                    new_session_kwargs["y"] = 600
-                session = self.server.new_session(
-                    session_name=self.session_config["session_name"],
-                    **new_session_kwargs,
+            new_session_kwargs = {}
+            if "start_directory" in self.session_config:
+                new_session_kwargs["start_directory"] = self.session_config[
+                    "start_directory"
+                ]
+
+            if (
+                has_gte_version("2.6")
+                and os.getenv("TMUXP_DETECT_TERMINAL_SIZE", "1") == "1"
+            ):
+                terminal_size = shutil.get_terminal_size(
+                    fallback=(get_default_columns(), get_default_rows()),
                 )
+                new_session_kwargs["x"] = terminal_size.columns
+                new_session_kwargs["y"] = terminal_size.lines
+
+            session = self.server.new_session(
+                session_name=self.session_config["session_name"],
+                **new_session_kwargs,
+            )
             assert session is not None
 
             assert self.session_config["session_name"] == session.name
@@ -248,7 +271,7 @@ class WorkspaceBuilder:
 
         assert session.server is not None
 
-        self.server: "Server" = session.server
+        self.server: Server = session.server
         assert self.server.sessions is not None
         assert self.server.has_session(session.name)
         assert session.id
@@ -355,7 +378,7 @@ class WorkspaceBuilder:
 
             w1 = None
             if is_first_window_pass:  # if first window, use window 1
-                w1 = session.attached_window
+                w1 = session.active_window
                 w1.move_window("99")
 
             start_directory = window_config.get("start_directory", None)
@@ -403,7 +426,7 @@ class WorkspaceBuilder:
             assert isinstance(window, Window)
 
             if is_first_window_pass:  # if first window, use window 1
-                session.attached_window.kill()
+                session.active_window.kill()
 
             if "options" in window_config and isinstance(
                 window_config["options"],
@@ -452,7 +475,7 @@ class WorkspaceBuilder:
             start=pane_base_index,
         ):
             if pane_index == int(pane_base_index):
-                pane = window.attached_pane
+                pane = window.active_pane
             else:
 
                 def get_pane_start_directory(
@@ -461,10 +484,9 @@ class WorkspaceBuilder:
                 ) -> t.Optional[str]:
                     if "start_directory" in pane_config:
                         return pane_config["start_directory"]
-                    elif "start_directory" in window_config:
+                    if "start_directory" in window_config:
                         return window_config["start_directory"]
-                    else:
-                        return None
+                    return None
 
                 def get_pane_shell(
                     pane_config: t.Dict[str, str],
@@ -472,10 +494,9 @@ class WorkspaceBuilder:
                 ) -> t.Optional[str]:
                     if "shell" in pane_config:
                         return pane_config["shell"]
-                    elif "window_shell" in window_config:
+                    if "window_shell" in window_config:
                         return window_config["window_shell"]
-                    else:
-                        return None
+                    return None
 
                 environment = pane_config.get(
                     "environment",
@@ -494,7 +515,7 @@ class WorkspaceBuilder:
 
                 assert pane is not None
 
-                pane = window.split_window(
+                pane = pane.split(
                     attach=True,
                     start_directory=get_pane_start_directory(
                         pane_config=pane_config,
@@ -504,7 +525,6 @@ class WorkspaceBuilder:
                         pane_config=pane_config,
                         window_config=window_config,
                     ),
-                    target=pane.id,
                     environment=environment,
                 )
 
@@ -574,7 +594,7 @@ class WorkspaceBuilder:
         current_active_pane = get_current_pane(self.server)
 
         if current_active_pane is None:
-            raise exc.ActiveSessionMissingWorkspaceException()
+            raise exc.ActiveSessionMissingWorkspaceException
 
         return next(
             (
