@@ -1,4 +1,5 @@
 """Workspace (configuration file) finders for tmuxp."""
+
 import logging
 import os
 import pathlib
@@ -66,14 +67,12 @@ def in_dir(
     if extensions is None:
         extensions = [".yml", ".yaml", ".json"]
 
-    workspace_files = [
+    return [
         filename
         for filename in os.listdir(workspace_dir)
         if is_workspace_file(filename, extensions) and not filename.startswith(".")
     ]
 
-    return workspace_files
-
 
 def in_cwd() -> t.List[str]:
     """
@@ -91,14 +90,12 @@ def in_cwd() -> t.List[str]:
     >>> sorted(in_cwd())
     ['.tmuxp.json', '.tmuxp.yaml']
     """
-    workspace_files = [
+    return [
         filename
         for filename in os.listdir(os.getcwd())
         if filename.startswith(".tmuxp") and is_workspace_file(filename)
     ]
 
-    return workspace_files
-
 
 def get_workspace_dir() -> str:
     """
@@ -175,9 +172,7 @@ def find_workspace_file(
     elif (
         not isabs(workspace_file)
         or len(dirname(workspace_file)) > 1
-        or workspace_file == "."
-        or workspace_file == ""
-        or workspace_file == "./"
+        or workspace_file in {".", "", "./"}
     ):  # if relative, fill in full path
         workspace_file = normpath(join(cwd, workspace_file))
 
@@ -194,8 +189,8 @@ def find_workspace_file(
             ]
             if not len(candidates):
                 file_error = (
-                    "workspace-file not found in workspace dir (yaml/yml/json) %s "
-                    "for name" % (workspace_dir)
+                    "workspace-file not found "
+                    + f"in workspace dir (yaml/yml/json) {workspace_dir} for name"
                 )
         else:
             candidates = [
@@ -210,8 +205,8 @@ def find_workspace_file(
             if len(candidates) > 1:
                 tmuxp_echo(
                     Fore.RED
-                    + "Multiple .tmuxp.{yml,yaml,json} workspace_files in %s"
-                    % dirname(workspace_file)
+                    + "Multiple .tmuxp.{yml,yaml,json} workspace_files in "
+                    + dirname(workspace_file)
                     + Fore.RESET,
                 )
                 tmuxp_echo(
@@ -250,6 +245,5 @@ def is_pure_name(path: str) -> bool:
         not os.path.isabs(path)
         and len(os.path.dirname(path)) == 0
         and not os.path.splitext(path)[1]
-        and path != "."
-        and path != ""
+        and path not in {".", ""}
     )
