@@ -1,4 +1,5 @@
 """Configuration import adapters to load teamocil, tmuxinator, etc. in tmuxp."""
+
 import typing as t
 
 
@@ -70,7 +71,7 @@ def import_tmuxinator(workspace_dict: t.Dict[str, t.Any]) -> t.Dict[str, t.Any]:
         if "shell_command_before" not in tmuxp_workspace:
             tmuxp_workspace["shell_command_before"] = []
         tmuxp_workspace["shell_command_before"].append(
-            "rbenv shell %s" % workspace_dict["rbenv"],
+            "rbenv shell {}".format(workspace_dict["rbenv"]),
         )
 
     for window_dict in workspace_dict["windows"]:
@@ -81,7 +82,7 @@ def import_tmuxinator(workspace_dict: t.Dict[str, t.Any]) -> t.Dict[str, t.Any]:
                 window_dict["panes"] = [v]
                 tmuxp_workspace["windows"].append(window_dict)
                 continue
-            elif isinstance(v, list):
+            if isinstance(v, list):
                 window_dict["panes"] = v
                 tmuxp_workspace["windows"].append(window_dict)
                 continue
@@ -156,7 +157,7 @@ def import_teamocil(workspace_dict: t.Dict[str, t.Any]) -> t.Dict[str, t.Any]:
                 if "cmd" in p:
                     p["shell_command"] = p.pop("cmd")
                 if "width" in p:
-                    # todo support for height/width
+                    # TODO support for height/width
                     p.pop("width")
             window_dict["panes"] = w["panes"]
 
