@@ -12,7 +12,7 @@ class LibtmuxVersionFailMinPlugin(MyTestTmuxpPlugin):
     """Tmuxp plugin that fails when libtmux below minimum version constraint."""
 
     def __init__(self) -> None:
-        config: "PluginTestConfigSchema" = {
+        config: PluginTestConfigSchema = {
             "plugin_name": "libtmux-min-version-fail",
             "libtmux_min_version": "0.8.3",
             "libtmux_version": "0.7.0",
@@ -24,7 +24,7 @@ class LibtmuxVersionFailMaxPlugin(MyTestTmuxpPlugin):
     """Tmuxp plugin that fails when libtmux above maximum version constraint."""
 
     def __init__(self) -> None:
-        config: "PluginTestConfigSchema" = {
+        config: PluginTestConfigSchema = {
             "plugin_name": "libtmux-max-version-fail",
             "libtmux_max_version": "3.0",
             "libtmux_version": "3.5",
@@ -36,7 +36,7 @@ class LibtmuxVersionFailIncompatiblePlugin(MyTestTmuxpPlugin):
     """Tmuxp plugin that fails when libtmux version constraint is invalid."""
 
     def __init__(self) -> None:
-        config: "PluginTestConfigSchema" = {
+        config: PluginTestConfigSchema = {
             "plugin_name": "libtmux-incompatible-version-fail",
             "libtmux_version_incompatible": ["0.7.1"],
             "libtmux_version": "0.7.1",
