@@ -1,4 +1,5 @@
 """Test for tmuxp workspace builder."""
+
 import functools
 import os
 import pathlib
@@ -17,15 +18,14 @@ from libtmux.session import Session
 from libtmux.test import retry_until, temp_session
 from libtmux.window import Window
 
+from tests.constants import EXAMPLE_PATH, FIXTURE_PATH
+from tests.fixtures import utils as test_utils
 from tmuxp import exc
 from tmuxp._internal.config_reader import ConfigReader
 from tmuxp.cli.load import load_plugins
 from tmuxp.workspace import loader
 from tmuxp.workspace.builder import WorkspaceBuilder
 
-from ..constants import EXAMPLE_PATH, FIXTURE_PATH
-from ..fixtures import utils as test_utils
-
 if t.TYPE_CHECKING:
 
     class AssertCallbackProtocol(t.Protocol):
@@ -92,9 +92,9 @@ def test_focus_pane_index(session: Session) -> None:
 
     builder.build(session=session)
 
-    assert session.attached_window.name == "focused window"
+    assert session.active_window.name == "focused window"
 
-    _pane_base_index = session.attached_window.show_window_option(
+    _pane_base_index = session.active_window.show_window_option(
         "pane-base-index",
         g=True,
     )
@@ -106,14 +106,14 @@ def test_focus_pane_index(session: Session) -> None:
     # get the pane index for each pane
     pane_base_indexes = [
         int(pane.index)
-        for pane in session.attached_window.panes
+        for pane in session.active_window.panes
         if pane is not None and pane.index is not None
     ]
 
-    pane_indexes_should_be = [pane_base_index + x for x in range(0, 3)]
+    pane_indexes_should_be = [pane_base_index + x for x in range(3)]
     assert pane_indexes_should_be == pane_base_indexes
 
-    w = session.attached_window
+    w = session.active_window
 
     assert w.name != "man"
 
@@ -122,7 +122,7 @@ def test_focus_pane_index(session: Session) -> None:
 
     def f_check() -> bool:
         nonlocal p
-        p = w.attached_pane
+        p = w.active_pane
         assert p is not None
         return p.pane_current_path == pane_path
 
@@ -142,7 +142,7 @@ def test_focus_pane_index(session: Session) -> None:
 
     def f_check_again() -> bool:
         nonlocal p
-        p = window3.attached_pane
+        p = window3.active_pane
         assert p is not None
         return p.pane_current_path == pane_path
 
@@ -188,7 +188,7 @@ def test_suppress_history(session: Session) -> None:
     ]:
         assert w.name == window_name
         w.select()
-        p = w.attached_pane
+        p = w.active_pane
         assert p is not None
         p.select()
 
@@ -279,7 +279,7 @@ def test_global_session_env_options(
     assert isinstance(_visual_silence, str)
     assert visual_silence in _visual_silence
     assert repeat_time == session.show_option("repeat-time")
-    assert main_pane_height == session.attached_window.show_window_option(
+    assert main_pane_height == session.active_window.show_window_option(
         "main-pane-height",
     )
 
@@ -338,7 +338,7 @@ def test_window_options_after(
         # Print output for easier debugging if assertion fails
         return retry_until(f, raises=False)
 
-    for i, pane in enumerate(session.attached_window.panes):
+    for i, pane in enumerate(session.active_window.panes):
         assert assert_last_line(pane, str(i)), (
             "Initial command did not execute properly/" + str(i)
         )
@@ -351,7 +351,7 @@ def test_window_options_after(
     session.cmd("send-keys", " echo moo")
     session.cmd("send-keys", "Enter")
 
-    for pane in session.attached_window.panes:
+    for pane in session.active_window.panes:
         assert assert_last_line(
             pane,
             "moo",
@@ -486,6 +486,8 @@ def test_automatic_rename_option(
 ) -> None:
     """Test workspace builder with automatic renaming enabled."""
     monkeypatch.setenv("DISABLE_AUTO_TITLE", "true")
+    monkeypatch.setenv("ROWS", "36")
+
     workspace = ConfigReader._from_file(
         test_utils.get_workspace_file("workspace/builder/window_automatic_rename.yaml"),
     )
@@ -512,10 +514,10 @@ def test_automatic_rename_option(
 
     def check_window_name_match() -> bool:
         assert w.show_window_option("automatic-rename") == "on"
-        return (
-            w.name == pathlib.Path(os.getenv("SHELL", "bash")).name
-            or w.name == portable_command
-        )
+        return w.name in {
+            pathlib.Path(os.getenv("SHELL", "bash")).name,
+            portable_command,
+        }
 
     assert retry_until(
         check_window_name_match,
@@ -1096,9 +1098,9 @@ def test_find_current_active_pane(
 
 
 @pytest.mark.parametrize(
-    "yaml,output,should_see",
+    ("yaml", "output", "should_see"),
     [
-        [
+        (
             textwrap.dedent(
                 """
 session_name: Should not execute
@@ -1110,8 +1112,8 @@ windows:
             ),
             "___4___",
             False,
-        ],
-        [
+        ),
+        (
             textwrap.dedent(
                 """
 session_name: Should not execute
@@ -1124,8 +1126,8 @@ windows:
             ),
             "___4___",
             False,
-        ],
-        [
+        ),
+        (
             textwrap.dedent(
                 """
 session_name: Should execute
@@ -1136,8 +1138,8 @@ windows:
             ),
             "___4___",
             True,
-        ],
-        [
+        ),
+        (
             textwrap.dedent(
                 """
 session_name: Should execute
@@ -1149,8 +1151,8 @@ windows:
             ),
             "___4___",
             True,
-        ],
-        [
+        ),
+        (
             textwrap.dedent(
                 """
 session_name: Should not execute
@@ -1163,8 +1165,8 @@ windows:
             ),
             "___4___",
             False,
-        ],
-        [
+        ),
+        (
             textwrap.dedent(
                 """
 session_name: Should not execute
@@ -1177,8 +1179,8 @@ windows:
             ),
             "___4___",
             False,
-        ],
-        [
+        ),
+        (
             textwrap.dedent(
                 """
 session_name: Should execute
@@ -1189,8 +1191,8 @@ windows:
             ),
             "___4___",
             True,
-        ],
-        [
+        ),
+        (
             textwrap.dedent(
                 """
 session_name: Should execute
@@ -1203,7 +1205,7 @@ windows:
             ),
             "___4___",
             True,
-        ],
+        ),
     ],
     ids=[
         "pane_enter_false_shortform",
@@ -1235,7 +1237,7 @@ def test_load_workspace_enter(
 
     session = builder.session
     assert isinstance(session, Session)
-    pane = session.attached_pane
+    pane = session.active_pane
     assert isinstance(pane, Pane)
 
     def fn() -> bool:
@@ -1243,8 +1245,7 @@ def test_load_workspace_enter(
 
         if should_see:
             return output in captured_pane
-        else:
-            return output not in captured_pane
+        return output not in captured_pane
 
     assert retry_until(
         fn,
@@ -1253,9 +1254,9 @@ def test_load_workspace_enter(
 
 
 @pytest.mark.parametrize(
-    "yaml,sleep,output",
+    ("yaml", "sleep", "output"),
     [
-        [
+        (
             textwrap.dedent(
                 """
 session_name: Should not execute
@@ -1270,8 +1271,8 @@ windows:
             ),
             0.5,
             "___4___",
-        ],
-        [
+        ),
+        (
             textwrap.dedent(
                 """
 session_name: Should not execute
@@ -1286,8 +1287,8 @@ windows:
             ),
             1.25,
             "___4___",
-        ],
-        [
+        ),
+        (
             textwrap.dedent(
                 """
 session_name: Should not execute
@@ -1300,8 +1301,8 @@ windows:
             ),
             0.5,
             "___4___",
-        ],
-        [
+        ),
+        (
             textwrap.dedent(
                 """
 session_name: Should not execute
@@ -1314,8 +1315,8 @@ windows:
             ),
             1,
             "___4___",
-        ],
-        [
+        ),
+        (
             textwrap.dedent(
                 """
 session_name: Should not execute
@@ -1329,7 +1330,7 @@ windows:
             ),
             0.5,
             "___4___",
-        ],
+        ),
     ],
     ids=[
         "command_level_sleep_shortform",
@@ -1363,7 +1364,7 @@ def test_load_workspace_sleep(
     session = builder.session
     assert isinstance(builder.session, Session)
     assert session is not None
-    pane = session.attached_pane
+    pane = session.active_pane
     assert isinstance(pane, Pane)
 
     assert pane is not None
@@ -1507,7 +1508,12 @@ def test_issue_800_default_size_many_windows(
     a lot of panes.
 
     See also: https://github.com/tmux-python/tmuxp/issues/800
+
+    2024-04-07: This test isn't being used as of this date, as default-size is totally
+    unused in builder.py.
     """
+    monkeypatch.setenv("ROWS", "36")
+
     yaml_workspace = test_utils.get_workspace_file(
         "regressions/issue_800_default_size_many_windows.yaml",
     )
@@ -1520,9 +1526,6 @@ def test_issue_800_default_size_many_windows(
         for k, v in confoverrides.items():
             workspace[k] = v
 
-    if TMUXP_DEFAULT_SIZE is not None:
-        monkeypatch.setenv("TMUXP_DEFAULT_SIZE", TMUXP_DEFAULT_SIZE)
-
     builder = WorkspaceBuilder(session_config=workspace, server=server)
 
     if raises:
